@@ -31,6 +31,7 @@ from ..tools.MetaReader import overwrite_beam, overwrite_detector
 from ..tools.VDS_tools import image_vds_writer, vds_file_writer
 from . import (
     add_tristan_spec,
+    config_parser,
     demo_parser,
     detectormode_parser,
     nexus_parser,
@@ -50,13 +51,12 @@ master_phil = freephil.parse(
     }
     input {
       datafile = None
-        .multiple = True
         .type = path
         .help = "HDF5 file. For now, assumes pattern filename_%0{6}d.h5"
       coordinate_frame = *mcstas imgcif
         .type = choice
         .help = "Which coordinate system is being used to provide input vectors."
-      vds_writer = *None dataset file
+      vds_writer = None *dataset file
         .type = choice
         .help = "If not None, write vds along with external link to data in NeXus file, or create _vds.h5 file."
       snaked = False
@@ -89,7 +89,7 @@ demo_phil = freephil.parse(
       coordinate_frame = *mcstas imgcif
         .type = choice
         .help = "Which coordinate system is being used to provide input vectors"
-      vds_writer = *None dataset file
+      vds_writer = None *dataset file
         .type = choice
         .help = "If not None, either write a vds in the nexus file or create also a _vds.h5 file."
       snaked = False
@@ -120,13 +120,12 @@ meta_phil = freephil.parse(
         .type = path
         .help = "Path to _meta.h5 file for collection."
       datafile = None
-        .multiple = True
         .type = path
         .help = "HDF5 file. For now, assumes pattern filename_%0{6}d.h5"
       coordinate_frame = *mcstas imgcif
         .type = choice
         .help = "Which coordinate system is being used to provide input vectors."
-      vds_writer = *None dataset file
+      vds_writer = None *dataset file
         .type = choice
         .help = "If not None, write vds along with external link to data in NeXus file, or create _vds.h5 file."
       snaked = False
@@ -149,26 +148,10 @@ meta_phil = freephil.parse(
 
 # Parse command line arguments
 parser = argparse.ArgumentParser(
-    description="Generate a NeXus file for data collection.",
+    description="Generate a new NeXus file for data collection.",
     parents=[version_parser],
 )
 parser.add_argument("--debug", action="store_const", const=True)
-parser.add_argument(
-    "-c",
-    "--show-config",
-    action="store_true",
-    default=False,
-    dest="show_config",
-    help="Show the configuration parameters.",
-)
-parser.add_argument(
-    "-a",
-    "--attributes-level",
-    default=0,
-    type=int,
-    dest="attributes_level",
-    help="Set the attributes level for showing the configuration parameters.",
-)
 
 
 # CLIs
@@ -182,7 +165,9 @@ def write_NXmx_cli(args):
         sys.exit()
 
     # Path to data file
-    datafiles = [Path(d).expanduser().resolve() for d in params.input.datafile]
+    datafiles = [
+        Path(d).expanduser().resolve() for d in glob.glob(params.input.datafile)
+    ]
 
     # Get NeXus file name
     if params.output.master_filename:
@@ -305,7 +290,7 @@ def write_NXmx_cli(args):
     )
     logger.info(f"Trusted pixels > {detector.underload} and < {detector.overload}")
     logger.info(
-        f"Image is a {detector.image_size} array of {detector.pixel_size} pixels"
+        f"Image is a {detector.image_size[::-1]} array of {detector.pixel_size} pixels"
     )
 
     logger.info("Detector axes:")
@@ -518,7 +503,7 @@ def write_demo_cli(args):
     if data_type[0] == "images":
         logger.info(f"Trusted pixels > {detector.underload} and < {detector.overload}")
     logger.info(
-        f"Image is a {detector.image_size} array of {detector.pixel_size} pixels"
+        f"Image is a {detector.image_size[::-1]} array of {detector.pixel_size} pixels"
     )
 
     logger.info("Detector axes:")
@@ -682,7 +667,9 @@ def write_with_meta_cli(args):
 
     # If no datafile has been passed, look for them in the directory
     if params.input.datafile:
-        datafiles = [Path(d).expanduser().resolve() for d in params.input.datafile]
+        datafiles = [
+            Path(d).expanduser().resolve() for d in glob.glob(params.input.datafile)
+        ]
     else:
         datafile_pattern = (
             metafile.parent / f"{master_file.stem}_{6*'[0-9]'}.h5"
@@ -810,7 +797,7 @@ def write_with_meta_cli(args):
     )
     logger.info(f"Trusted pixels > {detector.underload} and < {detector.overload}")
     logger.info(
-        f"Image is a {detector.image_size} array of {detector.pixel_size} pixels"
+        f"Image is a {detector.image_size[::-1]} array of {detector.pixel_size} pixels"
     )
 
     logger.info("Detector axes:")
@@ -935,15 +922,18 @@ parser_NXmx = subparsers.add_parser(
     "1",
     aliases=["nexus"],
     description=("Trigger NeXus file writing pointing to existing data."),
-    parents=[nexus_parser],
+    parents=[nexus_parser, config_parser],
 )
 parser_NXmx.set_defaults(func=write_NXmx_cli)
 
 parser_NXmx_demo = subparsers.add_parser(
     "2",
     aliases=["demo"],
-    description=("Trigger NeXus and blank data file writing."),
-    parents=[demo_parser, detectormode_parser],
+    description=(
+        "Trigger NeXus and blank data file writing. "
+        "This option always requires either the -i or -e flags, which are mutually exclusive arguments."
+    ),
+    parents=[demo_parser, detectormode_parser, config_parser],
 )
 parser_NXmx_demo.set_defaults(func=write_demo_cli)
 
@@ -953,7 +943,7 @@ parser_NXmx_meta = subparsers.add_parser(
     description=(
         "Trigger NeXus file writing pointing to an existing collection with a meta file."
     ),
-    parents=[nexus_parser],
+    parents=[nexus_parser, config_parser],
 )
 parser_NXmx_meta.add_argument(
     "-no",
